/*
 * File: nrt.c
 *
 * MATLAB Coder version            : 2.6
 * C/C++ source code generated on  : 02-Apr-2014 12:52:38
 */

/* Include files */
#include "nrt.h"

/* Function Definitions */

/*
 * This function will use a Newton Search Technique to find
 * the nth root of a number, a, to the tolerance, tol.
 *  The square root
 *  nrt(10,2), or nrt(10,2,1e-9)
 *  The "n" root
 *  nrt(10,n), or nrt(10,n,1e-9)
 * Arguments    : double varargin_1
 *                double varargin_2
 *                double varargin_3
 *                double *nth_rt
 *                double *iterations
 *                double hstry[50]
 * Return Type  : void
 */
void nrt(double varargin_1, double varargin_2, double varargin_3, double *nth_rt,
         double *iterations, double hstry[50])
{
  int notDone;
  double a;
  int cnt;
  double slope;
  if (varargin_1 < 0.0) {
    *nth_rt = 0.0;
    *iterations = 0.0;
    memset(&hstry[0], 0, 50U * sizeof(double));
  } else {
    /*  Given, "a", this function finds the nth root of a */
    /*  number by finding where: x^n-a=0. */
    notDone = 1;
    *nth_rt = 0.0;

    /* Refined Guess Initialization */
    a = 1.0;

    /* Initial Guess */
    cnt = -1;
    memset(&hstry[0], 0, 50U * sizeof(double));
    hstry[0] = 1.0;
    while (notDone != 0) {
      cnt++;

      /*  Our function is f=a^n-b and it's derivative is n*a^(n-1). */
      slope = varargin_2 * pow(a, varargin_2 - 1.0);

      /* square */
      *nth_rt = -((pow(a, varargin_2) - varargin_1) - slope * a) / slope;

      /* The new guess */
      hstry[cnt] = *nth_rt;
      if (fabs(*nth_rt - a) < varargin_3) {
        /* Break if it's converged */
        notDone = 0;
      } else if (cnt + 1 > 49) {
        /* after 50 iterations, stop */
        notDone = 0;
        *nth_rt = 0.0;
      } else {
        a = *nth_rt;
      }
    }

    /*  Determine iterations */
    *iterations = 0.0;
    notDone = 0;
    while ((notDone < 50) && (hstry[notDone] != 0.0)) {
      (*iterations)++;
      notDone++;
    }

    /* iterations=length(find(hstry~=0)); */
  }
}

/*
 * File trailer for nrt.c
 *
 * [EOF]
 */
